@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2023 - Sébastien Wilmet
+/* SPDX-FileCopyrightText: 2023-2024 - Sébastien Wilmet
  * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
@@ -14,7 +14,7 @@
 G_BEGIN_DECLS
 
 G_MODULE_EXPORT
-gboolean	gfls_utf8_has_very_long_line	(const gchar *str,
+const gchar *	gfls_utf8_find_very_long_line	(const gchar *str,
 						 guint        max_n_bytes_per_line);
 
 G_END_DECLS
